@@ -285,7 +285,7 @@ void ApplicationController::commitImport(ImportController *importController)
 
     // add or update trip group
     QString tripGroupId;
-    if (!tripGroupElements.isEmpty() && m_tripGroupMgr) { // TODO many unit tests don't provide m_tripGroupMgr, fix this eventually
+    if (!tripGroupElements.isEmpty()) {
         if (!importController->tripGroupId().isEmpty()) {
             tripGroupId = importController->tripGroupId();
             m_tripGroupMgr->addToGroup(tripGroupElements, tripGroupId);
@@ -533,6 +533,7 @@ bool ApplicationController::importBundle(KItinerary::File *file)
 {
     Importer importer(file);
     int count = 0;
+    int settingsCount = 0;
     {
         TripGroupingBlocker groupingBlocker(m_tripGroupMgr);
         QSignalBlocker blocker(this); // suppress infoMessage()
@@ -545,7 +546,12 @@ bool ApplicationController::importBundle(KItinerary::File *file)
         count += importer.importPasses(m_passMgr);
         count += importer.importHealthCertificates(healthCertificateManager());
         count += importer.importLiveData(m_liveDataMgr);
-        count += importer.importSettings();
+        settingsCount += importer.importSettings();
+    }
+
+    if (settingsCount > 0) {
+        Q_EMIT reloadSettings();
+        count += settingsCount;
     }
 
     if (count > 0) {
