@@ -30,6 +30,15 @@ JourneySectionModel::JourneySectionModel(QObject *parent)
         }
         Q_EMIT journeySectionChanged();
     });
+
+    connect(&m_updateTimer, &QTimer::timeout, this, [this]() {
+        if (!m_data.empty()) {
+            Q_EMIT dataChanged(index(0, 0), index(rowCount() - 1, 0));
+        }
+    });
+    m_updateTimer.setTimerType(Qt::VeryCoarseTimer);
+    m_updateTimer.setInterval(std::chrono::minutes(1));
+    m_updateTimer.setSingleShot(false);
 }
 
 JourneySectionModel::~JourneySectionModel() = default;
@@ -39,6 +48,11 @@ KPublicTransport::JourneySection JourneySectionModel::journeySection() const
     return m_journey;
 }
 
+int JourneySectionModel::sectionCount() const
+{
+    return rowCount();
+}
+
 void JourneySectionModel::setJourneySection(const KPublicTransport::JourneySection &section)
 {
     // is this an update to the current state? if so, try to avoid resetting the model
@@ -55,6 +69,12 @@ void JourneySectionModel::setJourneySection(const KPublicTransport::JourneySecti
     m_data.resize(m_journey.intermediateStops().size());
     endResetModel();
     Q_EMIT journeySectionChanged();
+
+    if (m_data.empty()) {
+        m_updateTimer.stop();
+    } else {
+        m_updateTimer.start();
+    }
 }
 
 int JourneySectionModel::rowCount(const QModelIndex &parent) const
@@ -72,6 +92,8 @@ QVariant JourneySectionModel::data(const QModelIndex &index, int role) const
     }
 
     switch (role) {
+    case Qt::DisplayRole:
+        return m_journey.intermediateStops()[index.row()].stopPoint().name();
     case LeadingSegmentLengthRole:
         return m_data[index.row()].leadingLength;
     case TrailingSegmentLengthtRole:
