@@ -14,10 +14,11 @@
 #include <KItinerary/LocationUtil>
 #include <KItinerary/Person>
 #include <KItinerary/Reservation>
-#include <KItinerary/TrainTrip>
 #include <KItinerary/Ticket>
+#include <KItinerary/TrainTrip>
 #include <KItinerary/Visit>
 
+#include <KPublicTransport/Feature>
 #include <KPublicTransport/Line>
 #include <KPublicTransport/RentalVehicle>
 
@@ -101,7 +102,7 @@ QString ReservationHelper::vdvOrganizationId(const QVariant &res)
     return {};
 }
 
-bool ReservationHelper::isUnbound(const QVariant& res)
+bool ReservationHelper::isUnbound(const QVariant &res)
 {
     if (JsonLd::isA<TrainReservation>(res)) {
         return !res.value<TrainReservation>().reservationFor().value<TrainTrip>().departureTime().isValid();
@@ -164,7 +165,7 @@ QString ReservationHelper::defaultIconName(const QVariant &res)
         return u"meeting-attending"_s;
     }
     if (JsonLd::isA<FoodEstablishmentReservation>(res)) {
-        return u"qrc:///images/foodestablishment.svg"_s;
+        return KPublicTransport::Feature::typeIconName(KPublicTransport::Feature::Restaurant);
     }
     if (JsonLd::isA<RentalCarReservation>(res)) {
         return KPublicTransport::RentalVehicle::vehicleTypeIconName(KPublicTransport::RentalVehicle::Car);
